import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CodeartifactClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CodeartifactClient";
import { DescribePackageRequest, DescribePackageResult } from "../models/models_0";
export interface DescribePackageCommandInput extends DescribePackageRequest {
}
export interface DescribePackageCommandOutput extends DescribePackageResult, __MetadataBearer {
}
/**
 * <p> Returns a
 *       <a href="https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageDescription.html">PackageDescription</a>
 *       object that contains information about the requested package.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CodeartifactClient, DescribePackageCommand } from "@aws-sdk/client-codeartifact"; // ES Modules import
 * // const { CodeartifactClient, DescribePackageCommand } = require("@aws-sdk/client-codeartifact"); // CommonJS import
 * const client = new CodeartifactClient(config);
 * const command = new DescribePackageCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribePackageCommandInput} for command's `input` shape.
 * @see {@link DescribePackageCommandOutput} for command's `response` shape.
 * @see {@link CodeartifactClientResolvedConfig | config} for CodeartifactClient's `config` shape.
 *
 */
export declare class DescribePackageCommand extends $Command<DescribePackageCommandInput, DescribePackageCommandOutput, CodeartifactClientResolvedConfig> {
    readonly input: DescribePackageCommandInput;
    constructor(input: DescribePackageCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CodeartifactClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribePackageCommandInput, DescribePackageCommandOutput>;
    private serialize;
    private deserialize;
}
