import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { Readable } from "stream";
import { CodeartifactServiceException as __BaseException } from "./CodeartifactServiceException";
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export declare enum AllowPublish {
  ALLOW = "ALLOW",
  BLOCK = "BLOCK",
}
export declare enum AllowUpstream {
  ALLOW = "ALLOW",
  BLOCK = "BLOCK",
}
export declare enum HashAlgorithm {
  MD5 = "MD5",
  SHA1 = "SHA-1",
  SHA256 = "SHA-256",
  SHA512 = "SHA-512",
}
export interface AssetSummary {
  name: string | undefined;
  size?: number;
  hashes?: Record<string, string>;
}
export interface AssociateExternalConnectionRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  externalConnection: string | undefined;
}
export declare enum PackageFormat {
  MAVEN = "maven",
  NPM = "npm",
  NUGET = "nuget",
  PYPI = "pypi",
}
export declare enum ExternalConnectionStatus {
  AVAILABLE = "Available",
}
export interface RepositoryExternalConnectionInfo {
  externalConnectionName?: string;
  packageFormat?: PackageFormat | string;
  status?: ExternalConnectionStatus | string;
}
export interface UpstreamRepositoryInfo {
  repositoryName?: string;
}
export interface RepositoryDescription {
  name?: string;
  administratorAccount?: string;
  domainName?: string;
  domainOwner?: string;
  arn?: string;
  description?: string;
  upstreams?: UpstreamRepositoryInfo[];
  externalConnections?: RepositoryExternalConnectionInfo[];
}
export interface AssociateExternalConnectionResult {
  repository?: RepositoryDescription;
}
export declare enum ResourceType {
  ASSET = "asset",
  DOMAIN = "domain",
  PACKAGE = "package",
  PACKAGE_VERSION = "package-version",
  REPOSITORY = "repository",
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  resourceId?: string;
  resourceType?: ResourceType | string;
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare class InternalServerException extends __BaseException {
  readonly name: "InternalServerException";
  readonly $fault: "server";
  constructor(
    opts: __ExceptionOptionType<InternalServerException, __BaseException>
  );
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  resourceId?: string;
  resourceType?: ResourceType | string;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  resourceId?: string;
  resourceType?: ResourceType | string;
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export declare class ThrottlingException extends __BaseException {
  readonly name: "ThrottlingException";
  readonly $fault: "client";
  retryAfterSeconds?: number;
  constructor(
    opts: __ExceptionOptionType<ThrottlingException, __BaseException>
  );
}
export declare enum ValidationExceptionReason {
  CANNOT_PARSE = "CANNOT_PARSE",
  ENCRYPTION_KEY_ERROR = "ENCRYPTION_KEY_ERROR",
  FIELD_VALIDATION_FAILED = "FIELD_VALIDATION_FAILED",
  OTHER = "OTHER",
  UNKNOWN_OPERATION = "UNKNOWN_OPERATION",
}
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  reason?: ValidationExceptionReason | string;
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export interface CopyPackageVersionsRequest {
  domain: string | undefined;
  domainOwner?: string;
  sourceRepository: string | undefined;
  destinationRepository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  versions?: string[];
  versionRevisions?: Record<string, string>;
  allowOverwrite?: boolean;
  includeFromUpstream?: boolean;
}
export declare enum PackageVersionErrorCode {
  ALREADY_EXISTS = "ALREADY_EXISTS",
  MISMATCHED_REVISION = "MISMATCHED_REVISION",
  MISMATCHED_STATUS = "MISMATCHED_STATUS",
  NOT_ALLOWED = "NOT_ALLOWED",
  NOT_FOUND = "NOT_FOUND",
  SKIPPED = "SKIPPED",
}
export interface PackageVersionError {
  errorCode?: PackageVersionErrorCode | string;
  errorMessage?: string;
}
export declare enum PackageVersionStatus {
  ARCHIVED = "Archived",
  DELETED = "Deleted",
  DISPOSED = "Disposed",
  PUBLISHED = "Published",
  UNFINISHED = "Unfinished",
  UNLISTED = "Unlisted",
}
export interface SuccessfulPackageVersionInfo {
  revision?: string;
  status?: PackageVersionStatus | string;
}
export interface CopyPackageVersionsResult {
  successfulVersions?: Record<string, SuccessfulPackageVersionInfo>;
  failedVersions?: Record<string, PackageVersionError>;
}
export interface Tag {
  key: string | undefined;
  value: string | undefined;
}
export interface CreateDomainRequest {
  domain: string | undefined;
  encryptionKey?: string;
  tags?: Tag[];
}
export declare enum DomainStatus {
  ACTIVE = "Active",
  DELETED = "Deleted",
}
export interface DomainDescription {
  name?: string;
  owner?: string;
  arn?: string;
  status?: DomainStatus | string;
  createdTime?: Date;
  encryptionKey?: string;
  repositoryCount?: number;
  assetSizeBytes?: number;
  s3BucketArn?: string;
}
export interface CreateDomainResult {
  domain?: DomainDescription;
}
export interface UpstreamRepository {
  repositoryName: string | undefined;
}
export interface CreateRepositoryRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  description?: string;
  upstreams?: UpstreamRepository[];
  tags?: Tag[];
}
export interface CreateRepositoryResult {
  repository?: RepositoryDescription;
}
export interface DeleteDomainRequest {
  domain: string | undefined;
  domainOwner?: string;
}
export interface DeleteDomainResult {
  domain?: DomainDescription;
}
export interface DeleteDomainPermissionsPolicyRequest {
  domain: string | undefined;
  domainOwner?: string;
  policyRevision?: string;
}
export interface ResourcePolicy {
  resourceArn?: string;
  revision?: string;
  document?: string;
}
export interface DeleteDomainPermissionsPolicyResult {
  policy?: ResourcePolicy;
}
export interface DeletePackageVersionsRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  versions: string[] | undefined;
  expectedStatus?: PackageVersionStatus | string;
}
export interface DeletePackageVersionsResult {
  successfulVersions?: Record<string, SuccessfulPackageVersionInfo>;
  failedVersions?: Record<string, PackageVersionError>;
}
export interface DeleteRepositoryRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
}
export interface DeleteRepositoryResult {
  repository?: RepositoryDescription;
}
export interface DeleteRepositoryPermissionsPolicyRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  policyRevision?: string;
}
export interface DeleteRepositoryPermissionsPolicyResult {
  policy?: ResourcePolicy;
}
export interface DescribeDomainRequest {
  domain: string | undefined;
  domainOwner?: string;
}
export interface DescribeDomainResult {
  domain?: DomainDescription;
}
export interface DescribePackageRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
}
export interface PackageOriginRestrictions {
  publish: AllowPublish | string | undefined;
  upstream: AllowUpstream | string | undefined;
}
export interface PackageOriginConfiguration {
  restrictions?: PackageOriginRestrictions;
}
export interface PackageDescription {
  format?: PackageFormat | string;
  namespace?: string;
  name?: string;
  originConfiguration?: PackageOriginConfiguration;
}
export interface DescribePackageResult {
  package: PackageDescription | undefined;
}
export interface DescribePackageVersionRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  packageVersion: string | undefined;
}
export interface LicenseInfo {
  name?: string;
  url?: string;
}
export interface DomainEntryPoint {
  repositoryName?: string;
  externalConnectionName?: string;
}
export declare enum PackageVersionOriginType {
  EXTERNAL = "EXTERNAL",
  INTERNAL = "INTERNAL",
  UNKNOWN = "UNKNOWN",
}
export interface PackageVersionOrigin {
  domainEntryPoint?: DomainEntryPoint;
  originType?: PackageVersionOriginType | string;
}
export interface PackageVersionDescription {
  format?: PackageFormat | string;
  namespace?: string;
  packageName?: string;
  displayName?: string;
  version?: string;
  summary?: string;
  homePage?: string;
  sourceCodeRepository?: string;
  publishedTime?: Date;
  licenses?: LicenseInfo[];
  revision?: string;
  status?: PackageVersionStatus | string;
  origin?: PackageVersionOrigin;
}
export interface DescribePackageVersionResult {
  packageVersion: PackageVersionDescription | undefined;
}
export interface DescribeRepositoryRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
}
export interface DescribeRepositoryResult {
  repository?: RepositoryDescription;
}
export interface DisassociateExternalConnectionRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  externalConnection: string | undefined;
}
export interface DisassociateExternalConnectionResult {
  repository?: RepositoryDescription;
}
export interface DisposePackageVersionsRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  versions: string[] | undefined;
  versionRevisions?: Record<string, string>;
  expectedStatus?: PackageVersionStatus | string;
}
export interface DisposePackageVersionsResult {
  successfulVersions?: Record<string, SuccessfulPackageVersionInfo>;
  failedVersions?: Record<string, PackageVersionError>;
}
export interface GetAuthorizationTokenRequest {
  domain: string | undefined;
  domainOwner?: string;
  durationSeconds?: number;
}
export interface GetAuthorizationTokenResult {
  authorizationToken?: string;
  expiration?: Date;
}
export interface GetDomainPermissionsPolicyRequest {
  domain: string | undefined;
  domainOwner?: string;
}
export interface GetDomainPermissionsPolicyResult {
  policy?: ResourcePolicy;
}
export interface GetPackageVersionAssetRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  packageVersion: string | undefined;
  asset: string | undefined;
  packageVersionRevision?: string;
}
export interface GetPackageVersionAssetResult {
  asset?: Readable | ReadableStream | Blob;
  assetName?: string;
  packageVersion?: string;
  packageVersionRevision?: string;
}
export interface GetPackageVersionReadmeRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  packageVersion: string | undefined;
}
export interface GetPackageVersionReadmeResult {
  format?: PackageFormat | string;
  namespace?: string;
  package?: string;
  version?: string;
  versionRevision?: string;
  readme?: string;
}
export interface GetRepositoryEndpointRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
}
export interface GetRepositoryEndpointResult {
  repositoryEndpoint?: string;
}
export interface GetRepositoryPermissionsPolicyRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
}
export interface GetRepositoryPermissionsPolicyResult {
  policy?: ResourcePolicy;
}
export interface ListDomainsRequest {
  maxResults?: number;
  nextToken?: string;
}
export interface DomainSummary {
  name?: string;
  owner?: string;
  arn?: string;
  status?: DomainStatus | string;
  createdTime?: Date;
  encryptionKey?: string;
}
export interface ListDomainsResult {
  domains?: DomainSummary[];
  nextToken?: string;
}
export interface ListPackagesRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format?: PackageFormat | string;
  namespace?: string;
  packagePrefix?: string;
  maxResults?: number;
  nextToken?: string;
  publish?: AllowPublish | string;
  upstream?: AllowUpstream | string;
}
export interface PackageSummary {
  format?: PackageFormat | string;
  namespace?: string;
  package?: string;
  originConfiguration?: PackageOriginConfiguration;
}
export interface ListPackagesResult {
  packages?: PackageSummary[];
  nextToken?: string;
}
export interface ListPackageVersionAssetsRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  packageVersion: string | undefined;
  maxResults?: number;
  nextToken?: string;
}
export interface ListPackageVersionAssetsResult {
  format?: PackageFormat | string;
  namespace?: string;
  package?: string;
  version?: string;
  versionRevision?: string;
  nextToken?: string;
  assets?: AssetSummary[];
}
export interface ListPackageVersionDependenciesRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  packageVersion: string | undefined;
  nextToken?: string;
}
export interface PackageDependency {
  namespace?: string;
  package?: string;
  dependencyType?: string;
  versionRequirement?: string;
}
export interface ListPackageVersionDependenciesResult {
  format?: PackageFormat | string;
  namespace?: string;
  package?: string;
  version?: string;
  versionRevision?: string;
  nextToken?: string;
  dependencies?: PackageDependency[];
}
export declare enum PackageVersionSortType {
  PUBLISHED_TIME = "PUBLISHED_TIME",
}
export interface ListPackageVersionsRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  status?: PackageVersionStatus | string;
  sortBy?: PackageVersionSortType | string;
  maxResults?: number;
  nextToken?: string;
  originType?: PackageVersionOriginType | string;
}
export interface PackageVersionSummary {
  version: string | undefined;
  revision?: string;
  status: PackageVersionStatus | string | undefined;
  origin?: PackageVersionOrigin;
}
export interface ListPackageVersionsResult {
  defaultDisplayVersion?: string;
  format?: PackageFormat | string;
  namespace?: string;
  package?: string;
  versions?: PackageVersionSummary[];
  nextToken?: string;
}
export interface ListRepositoriesRequest {
  repositoryPrefix?: string;
  maxResults?: number;
  nextToken?: string;
}
export interface RepositorySummary {
  name?: string;
  administratorAccount?: string;
  domainName?: string;
  domainOwner?: string;
  arn?: string;
  description?: string;
}
export interface ListRepositoriesResult {
  repositories?: RepositorySummary[];
  nextToken?: string;
}
export interface ListRepositoriesInDomainRequest {
  domain: string | undefined;
  domainOwner?: string;
  administratorAccount?: string;
  repositoryPrefix?: string;
  maxResults?: number;
  nextToken?: string;
}
export interface ListRepositoriesInDomainResult {
  repositories?: RepositorySummary[];
  nextToken?: string;
}
export interface ListTagsForResourceRequest {
  resourceArn: string | undefined;
}
export interface ListTagsForResourceResult {
  tags?: Tag[];
}
export interface PutDomainPermissionsPolicyRequest {
  domain: string | undefined;
  domainOwner?: string;
  policyRevision?: string;
  policyDocument: string | undefined;
}
export interface PutDomainPermissionsPolicyResult {
  policy?: ResourcePolicy;
}
export interface PutPackageOriginConfigurationRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  restrictions: PackageOriginRestrictions | undefined;
}
export interface PutPackageOriginConfigurationResult {
  originConfiguration?: PackageOriginConfiguration;
}
export interface PutRepositoryPermissionsPolicyRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  policyRevision?: string;
  policyDocument: string | undefined;
}
export interface PutRepositoryPermissionsPolicyResult {
  policy?: ResourcePolicy;
}
export interface TagResourceRequest {
  resourceArn: string | undefined;
  tags: Tag[] | undefined;
}
export interface TagResourceResult {}
export interface UntagResourceRequest {
  resourceArn: string | undefined;
  tagKeys: string[] | undefined;
}
export interface UntagResourceResult {}
export interface UpdatePackageVersionsStatusRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  format: PackageFormat | string | undefined;
  namespace?: string;
  package: string | undefined;
  versions: string[] | undefined;
  versionRevisions?: Record<string, string>;
  expectedStatus?: PackageVersionStatus | string;
  targetStatus: PackageVersionStatus | string | undefined;
}
export interface UpdatePackageVersionsStatusResult {
  successfulVersions?: Record<string, SuccessfulPackageVersionInfo>;
  failedVersions?: Record<string, PackageVersionError>;
}
export interface UpdateRepositoryRequest {
  domain: string | undefined;
  domainOwner?: string;
  repository: string | undefined;
  description?: string;
  upstreams?: UpstreamRepository[];
}
export interface UpdateRepositoryResult {
  repository?: RepositoryDescription;
}
export declare const AssetSummaryFilterSensitiveLog: (obj: AssetSummary) => any;
export declare const AssociateExternalConnectionRequestFilterSensitiveLog: (
  obj: AssociateExternalConnectionRequest
) => any;
export declare const RepositoryExternalConnectionInfoFilterSensitiveLog: (
  obj: RepositoryExternalConnectionInfo
) => any;
export declare const UpstreamRepositoryInfoFilterSensitiveLog: (
  obj: UpstreamRepositoryInfo
) => any;
export declare const RepositoryDescriptionFilterSensitiveLog: (
  obj: RepositoryDescription
) => any;
export declare const AssociateExternalConnectionResultFilterSensitiveLog: (
  obj: AssociateExternalConnectionResult
) => any;
export declare const CopyPackageVersionsRequestFilterSensitiveLog: (
  obj: CopyPackageVersionsRequest
) => any;
export declare const PackageVersionErrorFilterSensitiveLog: (
  obj: PackageVersionError
) => any;
export declare const SuccessfulPackageVersionInfoFilterSensitiveLog: (
  obj: SuccessfulPackageVersionInfo
) => any;
export declare const CopyPackageVersionsResultFilterSensitiveLog: (
  obj: CopyPackageVersionsResult
) => any;
export declare const TagFilterSensitiveLog: (obj: Tag) => any;
export declare const CreateDomainRequestFilterSensitiveLog: (
  obj: CreateDomainRequest
) => any;
export declare const DomainDescriptionFilterSensitiveLog: (
  obj: DomainDescription
) => any;
export declare const CreateDomainResultFilterSensitiveLog: (
  obj: CreateDomainResult
) => any;
export declare const UpstreamRepositoryFilterSensitiveLog: (
  obj: UpstreamRepository
) => any;
export declare const CreateRepositoryRequestFilterSensitiveLog: (
  obj: CreateRepositoryRequest
) => any;
export declare const CreateRepositoryResultFilterSensitiveLog: (
  obj: CreateRepositoryResult
) => any;
export declare const DeleteDomainRequestFilterSensitiveLog: (
  obj: DeleteDomainRequest
) => any;
export declare const DeleteDomainResultFilterSensitiveLog: (
  obj: DeleteDomainResult
) => any;
export declare const DeleteDomainPermissionsPolicyRequestFilterSensitiveLog: (
  obj: DeleteDomainPermissionsPolicyRequest
) => any;
export declare const ResourcePolicyFilterSensitiveLog: (
  obj: ResourcePolicy
) => any;
export declare const DeleteDomainPermissionsPolicyResultFilterSensitiveLog: (
  obj: DeleteDomainPermissionsPolicyResult
) => any;
export declare const DeletePackageVersionsRequestFilterSensitiveLog: (
  obj: DeletePackageVersionsRequest
) => any;
export declare const DeletePackageVersionsResultFilterSensitiveLog: (
  obj: DeletePackageVersionsResult
) => any;
export declare const DeleteRepositoryRequestFilterSensitiveLog: (
  obj: DeleteRepositoryRequest
) => any;
export declare const DeleteRepositoryResultFilterSensitiveLog: (
  obj: DeleteRepositoryResult
) => any;
export declare const DeleteRepositoryPermissionsPolicyRequestFilterSensitiveLog: (
  obj: DeleteRepositoryPermissionsPolicyRequest
) => any;
export declare const DeleteRepositoryPermissionsPolicyResultFilterSensitiveLog: (
  obj: DeleteRepositoryPermissionsPolicyResult
) => any;
export declare const DescribeDomainRequestFilterSensitiveLog: (
  obj: DescribeDomainRequest
) => any;
export declare const DescribeDomainResultFilterSensitiveLog: (
  obj: DescribeDomainResult
) => any;
export declare const DescribePackageRequestFilterSensitiveLog: (
  obj: DescribePackageRequest
) => any;
export declare const PackageOriginRestrictionsFilterSensitiveLog: (
  obj: PackageOriginRestrictions
) => any;
export declare const PackageOriginConfigurationFilterSensitiveLog: (
  obj: PackageOriginConfiguration
) => any;
export declare const PackageDescriptionFilterSensitiveLog: (
  obj: PackageDescription
) => any;
export declare const DescribePackageResultFilterSensitiveLog: (
  obj: DescribePackageResult
) => any;
export declare const DescribePackageVersionRequestFilterSensitiveLog: (
  obj: DescribePackageVersionRequest
) => any;
export declare const LicenseInfoFilterSensitiveLog: (obj: LicenseInfo) => any;
export declare const DomainEntryPointFilterSensitiveLog: (
  obj: DomainEntryPoint
) => any;
export declare const PackageVersionOriginFilterSensitiveLog: (
  obj: PackageVersionOrigin
) => any;
export declare const PackageVersionDescriptionFilterSensitiveLog: (
  obj: PackageVersionDescription
) => any;
export declare const DescribePackageVersionResultFilterSensitiveLog: (
  obj: DescribePackageVersionResult
) => any;
export declare const DescribeRepositoryRequestFilterSensitiveLog: (
  obj: DescribeRepositoryRequest
) => any;
export declare const DescribeRepositoryResultFilterSensitiveLog: (
  obj: DescribeRepositoryResult
) => any;
export declare const DisassociateExternalConnectionRequestFilterSensitiveLog: (
  obj: DisassociateExternalConnectionRequest
) => any;
export declare const DisassociateExternalConnectionResultFilterSensitiveLog: (
  obj: DisassociateExternalConnectionResult
) => any;
export declare const DisposePackageVersionsRequestFilterSensitiveLog: (
  obj: DisposePackageVersionsRequest
) => any;
export declare const DisposePackageVersionsResultFilterSensitiveLog: (
  obj: DisposePackageVersionsResult
) => any;
export declare const GetAuthorizationTokenRequestFilterSensitiveLog: (
  obj: GetAuthorizationTokenRequest
) => any;
export declare const GetAuthorizationTokenResultFilterSensitiveLog: (
  obj: GetAuthorizationTokenResult
) => any;
export declare const GetDomainPermissionsPolicyRequestFilterSensitiveLog: (
  obj: GetDomainPermissionsPolicyRequest
) => any;
export declare const GetDomainPermissionsPolicyResultFilterSensitiveLog: (
  obj: GetDomainPermissionsPolicyResult
) => any;
export declare const GetPackageVersionAssetRequestFilterSensitiveLog: (
  obj: GetPackageVersionAssetRequest
) => any;
export declare const GetPackageVersionAssetResultFilterSensitiveLog: (
  obj: GetPackageVersionAssetResult
) => any;
export declare const GetPackageVersionReadmeRequestFilterSensitiveLog: (
  obj: GetPackageVersionReadmeRequest
) => any;
export declare const GetPackageVersionReadmeResultFilterSensitiveLog: (
  obj: GetPackageVersionReadmeResult
) => any;
export declare const GetRepositoryEndpointRequestFilterSensitiveLog: (
  obj: GetRepositoryEndpointRequest
) => any;
export declare const GetRepositoryEndpointResultFilterSensitiveLog: (
  obj: GetRepositoryEndpointResult
) => any;
export declare const GetRepositoryPermissionsPolicyRequestFilterSensitiveLog: (
  obj: GetRepositoryPermissionsPolicyRequest
) => any;
export declare const GetRepositoryPermissionsPolicyResultFilterSensitiveLog: (
  obj: GetRepositoryPermissionsPolicyResult
) => any;
export declare const ListDomainsRequestFilterSensitiveLog: (
  obj: ListDomainsRequest
) => any;
export declare const DomainSummaryFilterSensitiveLog: (
  obj: DomainSummary
) => any;
export declare const ListDomainsResultFilterSensitiveLog: (
  obj: ListDomainsResult
) => any;
export declare const ListPackagesRequestFilterSensitiveLog: (
  obj: ListPackagesRequest
) => any;
export declare const PackageSummaryFilterSensitiveLog: (
  obj: PackageSummary
) => any;
export declare const ListPackagesResultFilterSensitiveLog: (
  obj: ListPackagesResult
) => any;
export declare const ListPackageVersionAssetsRequestFilterSensitiveLog: (
  obj: ListPackageVersionAssetsRequest
) => any;
export declare const ListPackageVersionAssetsResultFilterSensitiveLog: (
  obj: ListPackageVersionAssetsResult
) => any;
export declare const ListPackageVersionDependenciesRequestFilterSensitiveLog: (
  obj: ListPackageVersionDependenciesRequest
) => any;
export declare const PackageDependencyFilterSensitiveLog: (
  obj: PackageDependency
) => any;
export declare const ListPackageVersionDependenciesResultFilterSensitiveLog: (
  obj: ListPackageVersionDependenciesResult
) => any;
export declare const ListPackageVersionsRequestFilterSensitiveLog: (
  obj: ListPackageVersionsRequest
) => any;
export declare const PackageVersionSummaryFilterSensitiveLog: (
  obj: PackageVersionSummary
) => any;
export declare const ListPackageVersionsResultFilterSensitiveLog: (
  obj: ListPackageVersionsResult
) => any;
export declare const ListRepositoriesRequestFilterSensitiveLog: (
  obj: ListRepositoriesRequest
) => any;
export declare const RepositorySummaryFilterSensitiveLog: (
  obj: RepositorySummary
) => any;
export declare const ListRepositoriesResultFilterSensitiveLog: (
  obj: ListRepositoriesResult
) => any;
export declare const ListRepositoriesInDomainRequestFilterSensitiveLog: (
  obj: ListRepositoriesInDomainRequest
) => any;
export declare const ListRepositoriesInDomainResultFilterSensitiveLog: (
  obj: ListRepositoriesInDomainResult
) => any;
export declare const ListTagsForResourceRequestFilterSensitiveLog: (
  obj: ListTagsForResourceRequest
) => any;
export declare const ListTagsForResourceResultFilterSensitiveLog: (
  obj: ListTagsForResourceResult
) => any;
export declare const PutDomainPermissionsPolicyRequestFilterSensitiveLog: (
  obj: PutDomainPermissionsPolicyRequest
) => any;
export declare const PutDomainPermissionsPolicyResultFilterSensitiveLog: (
  obj: PutDomainPermissionsPolicyResult
) => any;
export declare const PutPackageOriginConfigurationRequestFilterSensitiveLog: (
  obj: PutPackageOriginConfigurationRequest
) => any;
export declare const PutPackageOriginConfigurationResultFilterSensitiveLog: (
  obj: PutPackageOriginConfigurationResult
) => any;
export declare const PutRepositoryPermissionsPolicyRequestFilterSensitiveLog: (
  obj: PutRepositoryPermissionsPolicyRequest
) => any;
export declare const PutRepositoryPermissionsPolicyResultFilterSensitiveLog: (
  obj: PutRepositoryPermissionsPolicyResult
) => any;
export declare const TagResourceRequestFilterSensitiveLog: (
  obj: TagResourceRequest
) => any;
export declare const TagResourceResultFilterSensitiveLog: (
  obj: TagResourceResult
) => any;
export declare const UntagResourceRequestFilterSensitiveLog: (
  obj: UntagResourceRequest
) => any;
export declare const UntagResourceResultFilterSensitiveLog: (
  obj: UntagResourceResult
) => any;
export declare const UpdatePackageVersionsStatusRequestFilterSensitiveLog: (
  obj: UpdatePackageVersionsStatusRequest
) => any;
export declare const UpdatePackageVersionsStatusResultFilterSensitiveLog: (
  obj: UpdatePackageVersionsStatusResult
) => any;
export declare const UpdateRepositoryRequestFilterSensitiveLog: (
  obj: UpdateRepositoryRequest
) => any;
export declare const UpdateRepositoryResultFilterSensitiveLog: (
  obj: UpdateRepositoryResult
) => any;
